alignAxis: Align to axis (deprecated)

View source: R/geom_rotate.R

alignAxisR Documentation

Align to axis (deprecated)

Description

[Deprecated]

This function is obsolete. Please use the more general rotate_v2v() function instead.

Usage

alignAxis(l, coords)

Arguments

l

A 2X3 matrix-like object containing xyz point coordinates defining the alignment vector, one coordinate per row.

coords

A Nx3 matrix-like object containing xyz point coordinates, one per row.

Value

A list containing rotated coordinates (coords) and the rotated input vector (l).

Author(s)

Cornel M. Pop


cornelmpop/Lithics3D documentation built on Feb. 10, 2024, 11:54 p.m.