mesh_triangles: Produce a list of mesh triangles with vertex coordinates

View source: R/transMeshIT.R

mesh_trianglesR Documentation

Produce a list of mesh triangles with vertex coordinates

Description

Returns a list of triangles defined by 3 vertices (v1, v2, v3).

Usage

mesh_triangles(mesh)

Arguments

mesh

mesh3d, or mesh3d-like object

Value

list object

Examples

data(demoSphere)
triangles <- mesh_triangles(demoSphere)
triangles[[1]]

cornelmpop/Lithics3D documentation built on Feb. 10, 2024, 11:54 p.m.