| alignAxis | R Documentation |
This function is obsolete. Please use the more general
rotate_v2v() function instead.
alignAxis(l, coords)
l |
A 2X3 matrix-like object containing xyz point coordinates defining the alignment vector, one coordinate per row. |
coords |
A Nx3 matrix-like object containing xyz point coordinates, one per row. |
A list containing rotated coordinates (coords) and the rotated input vector (l).
Cornel M. Pop
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.