| dist_pt2l | R Documentation |
Computes the minimum distance between points and a line
Computes minimum distances between a given set of 3D coordinates and a line
dist_pt2l(coords, l)
coords |
A Nx3 matrix-like object with point coordinates, one per row. |
l |
A 2x3 matrix-like object with coordinates defining a line, one coordinate per row. |
A vector of distances.
Tests
This is a very simple distance function. The orthogonal projection of the point onto the line is done by proj_pt2l
Cornel M. Pop
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.