| mesh_translate_it | R Documentation |
Translates triangle definitions (mesh3d$it) to a dataframe containing vertex coordinates instead of vertex IDs.
mesh_translate_it(mesh)
mesh |
mesh3d, or mesh3d-like object |
data.frame object
Only the first three rows of the mesh3d$it and mesh3d$vb matrices are used at the moment. For each row in the mesh3d$it matrix, which contains a list of column IDs from the mesh3d$vb matrix, three columns are created, in input order, for a total of 9 columns. These columns contain the row data from the mesh3d$vb matrix for the specified columns. Note that value types are not modified (e.g. double in the input == double in the output)
data(demoSphere)
coords <- mesh_translate_it(demoSphere)
head(coords)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.